@@ -46,12 +46,12 @@ class HTTPAuthorization(Auth):
         auth_string = None
         if m == None:
             self.logger.debug('invalid authorization string')
+        elif m[1].lower() == 'bearer':
+            (auth_string, retriever) = self.__handle_bearer(m[2], fetcher, client_id)
         elif m[1].lower() == 'basic':
             (auth_string, retriever) = self.__handle_basic(m[2], fetcher, client_id)
         elif m[1].lower() == 'hoba':
             (auth_string, retriever) = self.__handle_hoba(m[2], fetcher, client_id)
-        elif m[1].lower() == 'bearer':
-            (auth_string, retriever) = self.__handle_bearer(m[2], fetcher, client_id)
         else:
             self.logger.warning('unhandled authorization scheme {}'.format(m[0]))
        
@@ -62,7 +62,19 @@ class HTTPAuthorization(Auth):
     def __handle_bearer(self, s, f, c):
         HTTPAuthorization.component_id = 'http-bearer'
         self.logger.debug('set component id {}'.format(self.component_id))
-        return (bytes.fromhex(s), f)
+        try:
+            auth_string = bytes.fromhex(s)
+            return auth_string, f
+        except:
+            pass
+        
+        try:
+            auth_string = base64.b64decode(s)
+            return auth_string, f
+        except:
+            auth_string = s
+
+        return (auth_string, g)
 
 
     # Handler code for "Authorization: HOBA" scheme
